@@ -18,6 +18,7 @@
 import copy
 import math
 
+import ddt
 import mock
 from oslotest import base as test_base
 import six
@@ -150,6 +151,21 @@ class StrUtilsTest(test_base.BaseTestCase):
         self.assertEqual(1, strutils.int_from_bool_as_string(True))
         self.assertEqual(0, strutils.int_from_bool_as_string(False))
 
+    def test_is_valid_boolstr(self):
+        self.assertTrue(strutils.is_valid_boolstr('true'))
+        self.assertTrue(strutils.is_valid_boolstr('false'))
+        self.assertTrue(strutils.is_valid_boolstr('yes'))
+        self.assertTrue(strutils.is_valid_boolstr('no'))
+        self.assertTrue(strutils.is_valid_boolstr('y'))
+        self.assertTrue(strutils.is_valid_boolstr('n'))
+        self.assertTrue(strutils.is_valid_boolstr('1'))
+        self.assertTrue(strutils.is_valid_boolstr('0'))
+        self.assertTrue(strutils.is_valid_boolstr(1))
+        self.assertTrue(strutils.is_valid_boolstr(0))
+
+        self.assertFalse(strutils.is_valid_boolstr('maybe'))
+        self.assertFalse(strutils.is_valid_boolstr('only on tuesdays'))
+
     def test_slugify(self):
         to_slug = strutils.to_slug
         self.assertRaises(TypeError, to_slug, True)
@@ -171,6 +187,7 @@ class StringToBytesTest(test_base.BaseTestCase):
     _unit_system = [
         ('si', dict(unit_system='SI')),
         ('iec', dict(unit_system='IEC')),
+        ('mixed', dict(unit_system='mixed')),
         ('invalid_unit_system', dict(unit_system='KKK', assert_error=True)),
     ]
 
@@ -243,6 +260,14 @@ class StringToBytesTest(test_base.BaseTestCase):
                     res = getattr(units, unit_prefix)
                 else:
                     res = getattr(units, '%si' % unit_prefix)
+            elif unit_system == 'mixed':
+                # Note: this will return 'i' units as power-of-two,
+                # and other units as power-of-ten.  Additionally, for
+                # compatability a "K" is interpreted as "k" in mixed
+                # mode
+                if unit_prefix == 'K':
+                    unit_prefix = 'k'
+                res = getattr(units, unit_prefix)
             return res
 
         text = ''.join([self.sign, self.magnitude, self.unit_prefix,
@@ -327,6 +352,43 @@ class MaskPasswordTestCase(test_base.BaseTestCase):
         payload = """{ 'token' : 'token' }"""
         expected = """{ 'token' : '***' }"""
         self.assertEqual(expected, strutils.mask_password(payload))
+        # Test 'fernetkey'
+        payload = """{ 'fernetkey' : 'token' }"""
+        expected = """{ 'fernetkey' : '***' }"""
+        self.assertEqual(expected, strutils.mask_password(payload))
+        # Test 'FernetKey'
+        payload = """{ 'FernetKey' : 'token' }"""
+        expected = """{ 'FernetKey' : '***' }"""
+        self.assertEqual(expected, strutils.mask_password(payload))
+        # Test 'sslkey'
+        payload = """{ 'sslkey' : 'token' }"""
+        expected = """{ 'sslkey' : '***' }"""
+        self.assertEqual(expected, strutils.mask_password(payload))
+        # Test 'SslKey'
+        payload = """{ 'SslKey' : 'token' }"""
+        expected = """{ 'SslKey' : '***' }"""
+        self.assertEqual(expected, strutils.mask_password(payload))
+        # Test 'passphrase'
+        payload = """{ 'passphrase' : 'token' }"""
+        expected = """{ 'passphrase' : '***' }"""
+        self.assertEqual(expected, strutils.mask_password(payload))
+        # Test 'PassPhrase'
+        payload = """{ 'PassPhrase' : 'token' }"""
+        expected = """{ 'PassPhrase' : '***' }"""
+        self.assertEqual(expected, strutils.mask_password(payload))
+        # Some real-life cases
+        # Test 'KeystoneFernetKey1'
+        payload = """{ 'KeystoneFernetKey1' : 'token' }"""
+        expected = """{ 'KeystoneFernetKey1' : '***' }"""
+        self.assertEqual(expected, strutils.mask_password(payload))
+        # Test 'OctaviaCaKeyPassword'
+        payload = """{ 'OctaviaCaKeyPassword' : 'token' }"""
+        expected = """{ 'OctaviaCaKeyPassword' : '***' }"""
+        self.assertEqual(expected, strutils.mask_password(payload))
+        # Test 'OctaviaCaKeyPassphrase'
+        payload = """{ 'OctaviaCaKeyPassphrase' : 'token' }"""
+        expected = """{ 'OctaviaCaKeyPassphrase' : '***' }"""
+        self.assertEqual(expected, strutils.mask_password(payload))
 
     def test_xml(self):
         # Test 'adminPass' w/o spaces
@@ -369,6 +431,10 @@ class MaskPasswordTestCase(test_base.BaseTestCase):
                      </password>"""
         expected = """<password>***</password>"""
         self.assertEqual(expected, strutils.mask_password(payload))
+        # Test 'Password1' - case-insensitive + number
+        payload = """<Password1>TL0EfN33</Password1>"""
+        expected = """<Password1>***</Password1>"""
+        self.assertEqual(expected, strutils.mask_password(payload))
 
     def test_xml_attribute(self):
         # Test 'adminPass' w/o spaces
@@ -433,6 +499,9 @@ class MaskPasswordTestCase(test_base.BaseTestCase):
         payload = """body: {"rescue": {"password": "1234567"}}"""
         expected = """body: {"rescue": {"password": "***"}}"""
         self.assertEqual(expected, strutils.mask_password(payload))
+        payload = """body: {"rescue": {"encryption_key_id": "1234567"}}"""
+        expected = """body: {"rescue": {"encryption_key_id": "***"}}"""
+        self.assertEqual(expected, strutils.mask_password(payload))
 
     def test_xml_message(self):
         payload = """<?xml version="1.0" encoding="UTF-8"?>
@@ -622,6 +691,16 @@ class MaskDictionaryPasswordTestCase(test_base.BaseTestCase):
         self.assertEqual(expected,
                          strutils.mask_dict_password(payload))
 
+        payload = {'passwords': {'KeystoneFernetKey1': 'c5FijjS'}}
+        expected = {'passwords': {'KeystoneFernetKey1': '***'}}
+        self.assertEqual(expected,
+                         strutils.mask_dict_password(payload))
+
+        payload = {'passwords': {'keystonecredential0': 'c5FijjS'}}
+        expected = {'passwords': {'keystonecredential0': '***'}}
+        self.assertEqual(expected,
+                         strutils.mask_dict_password(payload))
+
     def test_do_no_harm(self):
         payload = {}
         expected = {}
@@ -635,6 +714,13 @@ class MaskDictionaryPasswordTestCase(test_base.BaseTestCase):
         self.assertEqual(expected,
                          strutils.mask_dict_password(payload))
 
+    def test_do_an_int(self):
+        payload = {}
+        payload[1] = 2
+        expected = payload.copy()
+        self.assertEqual(expected,
+                         strutils.mask_dict_password(payload))
+
     def test_mask_values(self):
         payload = {'somekey': 'test = cmd --password my\xe9\x80\x80pass'}
         expected = {'somekey': 'test = cmd --password ***'}
@@ -762,3 +848,62 @@ class SplitPathTestCase(test_base.BaseTestCase):
             strutils.split_path('o\nn e', 2, 3, True)
         except ValueError as err:
             self.assertEqual(str(err), 'Invalid path: o%0An%20e')
+
+
+class SplitByCommas(test_base.BaseTestCase):
+    def test_not_closed_quotes(self):
+        self.assertRaises(ValueError, strutils.split_by_commas, '"ab","b""')
+
+    def test_no_comma_before_opening_quotes(self):
+        self.assertRaises(ValueError, strutils.split_by_commas, '"ab""b"')
+
+    def test_quote_inside_unquoted(self):
+        self.assertRaises(ValueError, strutils.split_by_commas, 'a"b,cd')
+
+    def check(self, expect, input):
+        self.assertEqual(expect, strutils.split_by_commas(input))
+
+    def test_plain(self):
+        self.check(["a,b", "ac"], '"a,b",ac')
+
+    def test_with_backslash_inside_quoted(self):
+        self.check(['abc"', 'de', 'fg,h', 'klm\\', '"nop'],
+                   r'"abc\"","de","fg,h","klm\\","\"nop"')
+
+    def test_with_backslash_inside_unquoted(self):
+        self.check([r'a\bc', 'de'], r'a\bc,de')
+
+    def test_with_escaped_quotes_in_row_inside_quoted(self):
+        self.check(['a"b""c', 'd'], r'"a\"b\"\"c",d')
+
+
+@ddt.ddt
+class ValidateIntegerTestCase(test_base.BaseTestCase):
+
+    @ddt.unpack
+    @ddt.data({"value": 42, "name": "answer", "output": 42},
+              {"value": "42", "name": "answer", "output": 42},
+              {"value": "7", "name": "lucky", "output": 7,
+               "min_value": 7, "max_value": 8},
+              {"value": 7, "name": "lucky", "output": 7,
+               "min_value": 6, "max_value": 7},
+              {"value": 300, "name": "Spartaaa!!!", "output": 300,
+               "min_value": 300},
+              {"value": "300", "name": "Spartaaa!!!", "output": 300,
+               "max_value": 300})
+    def test_valid_inputs(self, output, value, name, **kwargs):
+        self.assertEqual(strutils.validate_integer(value, name,
+                                                   **kwargs), output)
+
+    @ddt.unpack
+    @ddt.data({"value": "im-not-an-int", "name": ''},
+              {"value": 3.14, "name": "Pie"},
+              {"value": "299", "name": "Sparta no-show",
+               "min_value": 300, "max_value": 300},
+              {"value": 55, "name": "doing 55 in a 54",
+               "max_value": 54},
+              {"value": six.unichr(129), "name": "UnicodeError",
+               "max_value": 1000})
+    def test_invalid_inputs(self, value, name, **kwargs):
+        self.assertRaises(ValueError, strutils.validate_integer,
+                          value, name, **kwargs)
